Crate so_defi_config

Crate so_defi_config 

provides helpers for parsing configuration data related to the Orca and Raydium AMMs from their respective configuration api

Modules

atrix
provides helepr functions for parsing atrix’s configuration api
orca
providers helper functions for parsing Orca’s configuration api and generating rust types corresponding to the emitted JSON
raydium
provides helepr functions for parsing raydium’s configuration api
whirlpool